# Table of Contents

- [sap-discovery](<./sap-discovery.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP Discovery](<./SAP-Discovery.md>)
  - [Overview](<./SAP-Discovery/Overview.md>)
  - [Benefits](<./SAP-Discovery/Benefits.md>)
  - [Available Integrations](<./SAP-Discovery/Available-Integrations.md>)
  - [SAP Discovery Inbox](<./SAP-Discovery/SAP-Discovery-Inbox.md>)
  - [Access and License Requirements](<./SAP-Discovery/Access-and-License-Requirements.md>)
